==> haskell-pandoc-server-0.1.0.5-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-15UUqXjewTFyT9h5vbqeL
key:                  pandoc-server-0.1.0.5-15UUqXjewTFyT9h5vbqeL
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  e539d0a2f30511fa8265503668a9589b
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-15UUqXjewTFyT9h5vbqeL
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    base64-bytestring-1.2.1.0-IHt64Gotm2vFOEZhD5akU7
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    doctemplates-0.11-Dpohx8aMJDGLtGnfT9sqrP
    pandoc-3.1.8-3ccdAF2j3ToDhVpivODqEj
    pandoc-types-1.23.1-6iBWeANyBCx4yQukPF7cP1
    servant-server-0.20-GovCk4T1MDfIXgn3AT54p9
    skylighting-0.14-DNbswYhj0UZ2lQfTsNRHq2 text-1.2.5.0
    unicode-collation-0.1.3.6-SC8exjsSHvqyiAeGQRaQ
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU
    wai-cors-0.2.7-3Lhsk9b62bC9TKpztGAmAx

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-server-0.1.0.5-73-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-FRpemelrRBY7socrioItwz
key:                  pandoc-server-0.1.0.5-FRpemelrRBY7socrioItwz
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  b39daa632a09d6a5942273a1a8b37498
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-FRpemelrRBY7socrioItwz
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj bytestring-0.11.4.0
    containers-0.6.5.1 data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    doctemplates-0.11-C27zRlWEVxT91PVtji9RxN
    pandoc-3.1.11-2h8qSqwWhzsFX4oHPfhgYO
    pandoc-types-1.23.1-9zMZjeuwTZD9DvwIlvEps5
    servant-server-0.20.2-AYzGtpbwaABAK0QjJ2xCb7
    skylighting-0.14.1-G3gCChLxKEBlm9tSf1APh text-1.2.5.0
    unicode-collation-0.1.3.6-KkFk90KA8ApFAAscEITKxS
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    wai-cors-0.2.7-86BvmItfNh66bTSJzWouQg

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
